@@ -152,7 +152,7 @@ class Git:
             {self.get_object_rsa(head1)[:SHORT_HASH_LEN]} and before {self.get_object_rsa(head2)[:SHORT_HASH_LEN]}"
     
     def get_formated_body_from_scratch(self):
-        return _run_shell_command(["git", "rev-list", "HEAD", "--format="+self.commit_format["log"]])
+        return _run_shell_command(["git", "rev-list", "HEAD", "--format="+quoted_str(self.commit_format["log"])])
 
     def get_object_rsa(self, obj):
         return _run_shell_command(["git", "rev-parse", obj])
@@ -217,8 +217,8 @@ class Git:
         logger.info(f"The config has been updated. The the url of {remote} remote is {out}.")
 
     @stop_timeout_exception
-    def fetch_branch(self, repo, branch):
-        return _run_shell_command(["git", "fetch", repo, branch])
+    def fetch_branch(self, remote, branch):
+        return _run_shell_command(["git", "fetch", remote, branch])
     
 
     def set_upper_branch(self, remote_branch, local_branch):
